@@ -20,17 +20,17 @@ distname = 'astroid'
 
 modname = 'astroid'
 
-numversion = (1, 4, 5)
+numversion = (1, 4, 7)
 version = '.'.join([str(num) for num in numversion])
 
 install_requires = ['six', 'lazy_object_proxy', 'wrapt']
 
 license = 'LGPL'
 
-author = 'Logilab'
-author_email = 'pylint-dev@lists.logilab.org'
+author = 'Python Code Quality Authority'
+author_email = 'code-quality@python.org'
 mailinglist = "mailto://%s" % author_email
-web = 'http://bitbucket.org/logilab/astroid'
+web = 'https://github.com/PyCQA/astroid'
 
 description = "A abstract syntax tree for Python with inference support."
 
